@@ -44,6 +44,7 @@ QAbstractFileEngine *DDciFileEngineHandler::create(const QString &fileName) cons
 #else
     DDciFileEngine *engine = new DDciFileEngine(fileName);
 #endif
+
     if (!engine->isValid()) {
 #if QT_VERSION < QT_VERSION_CHECK(6, 8, 0)
         delete engine;
@@ -56,8 +57,7 @@ QAbstractFileEngine *DDciFileEngineHandler::create(const QString &fileName) cons
 
 // 共享同个线程内的同个 DDciFile
 static thread_local QHash<QString, QWeakPointer<DDciFile>> sharedDciFile;
-static void doDeleteSharedDciFile(const QString &path, DDciFile *file)
-{
+static void doDeleteSharedDciFile(const QString &path, DDciFile *file) {
     int count = sharedDciFile.remove(path);
     Q_ASSERT(count > 0);
     delete file;
@@ -70,7 +70,8 @@ static DDciFileShared getDciFile(const QString &dciFilePath, bool usePath = true
     }
 
     DDciFileShared shared(usePath ? new DDciFile(dciFilePath) : new DDciFile(),
-                          std::bind(doDeleteSharedDciFile, dciFilePath, std::placeholders::_1));
+                          std::bind(doDeleteSharedDciFile, dciFilePath,
+                                    std::placeholders::_1));
     sharedDciFile[dciFilePath] = shared.toWeakRef();
     return shared;
 }
@@ -82,25 +83,33 @@ DDciFileEngineIterator::DDciFileEngineIterator(QDir::Filters filters, const QStr
     : QAbstractFileEngineIterator(filters, nameFilters)
 #endif
 {
+
 }
 
+#if QT_VERSION >= QT_VERSION_CHECK(6, 8, 1)
+DDciFileEngineIterator::DDciFileEngineIterator(QDirListing::IteratorFlags filters, const QStringList &nameFilters)
+    : QAbstractFileEngineIterator(nullptr, filters, nameFilters)
+{
+
+}
+#endif
+
 #if QT_VERSION < QT_VERSION_CHECK(6, 8, 0)
 QString DDciFileEngineIterator::next()
 {
     current = nextValid;
     return DDciFileEngineIterator::currentFileName();
 }
-#endif
 
-#if QT_VERSION >= QT_VERSION_CHECK(6, 8, 0)
-bool DDciFileEngineIterator::advance()
-#else
 bool DDciFileEngineIterator::hasNext() const
+#else
+bool DDciFileEngineIterator::advance()
 #endif
 {
     if (!file) {
         const auto paths = DDciFileEngine::resolvePath(path());
-        if (paths.first.isEmpty() || paths.second.isEmpty())
+        if (paths.first.isEmpty()
+                || paths.second.isEmpty())
             return false;
 
         file = getDciFile(paths.first);
@@ -120,7 +129,7 @@ bool DDciFileEngineIterator::hasNext() const
         } else if (fileType == DDciFile::Symlink) {
             if (filters.testFlag(QDir::NoSymLinks))
                 continue;
-        } else {  // DDciFile::UnknowFile
+        } else { // DDciFile::UnknowFile
             continue;
         }
 
@@ -198,7 +207,8 @@ bool DDciFileEngine::open(QIODevice::OpenMode openMode)
         }
     }
 
-    if ((openMode & QIODevice::ExistingOnly) || !(openMode & QIODevice::WriteOnly)) {
+    if ((openMode & QIODevice::ExistingOnly)
+            || !(openMode & QIODevice::WriteOnly)) {
         if (!file->exists(subfilePath)) {
             setError(QFile::OpenError, "The file is not exists");
             return false;
@@ -219,7 +229,8 @@ bool DDciFileEngine::open(QIODevice::OpenMode openMode)
 #endif
 
         // 不存在时尝试新建
-        if (!file->exists(subfilePath) && !file->writeFile(subfilePath, QByteArray())) {
+        if (!file->exists(subfilePath)
+                && !file->writeFile(subfilePath, QByteArray())) {
             return false;
         }
     }
@@ -509,22 +520,24 @@ QAbstractFileEngine::FileFlags DDciFileEngine::fileFlags(QAbstractFileEngine::Fi
 QString DDciFileEngine::fileName(QAbstractFileEngine::FileName file) const
 {
     switch (file) {
-        case AbsoluteName:
-        case CanonicalName:
-        case DefaultName:
-            return QDir::cleanPath(DCI_FILE_SCHEME + dciFilePath + subfilePath);
-        case AbsolutePathName:
-            return QDir::cleanPath(DCI_FILE_SCHEME + dciFilePath);
-        case BaseName:
-            return QFileInfo(subfilePath).baseName();
+    case AbsoluteName:
+    case CanonicalName:
+    case DefaultName:
+        return QDir::cleanPath(DCI_FILE_SCHEME + dciFilePath + subfilePath);
+    case AbsolutePathName:
+        return QDir::cleanPath(DCI_FILE_SCHEME + dciFilePath);
+    case BaseName:
+        return QFileInfo(subfilePath).baseName();
 #if QT_VERSION >= QT_VERSION_CHECK(6, 4, 0)
-        case AbsoluteLinkTarget:
+    case AbsoluteLinkTarget:
 #else
-        case LinkName:
+    case LinkName:
 #endif
-            return this->file->type(subfilePath) == DDciFile::Symlink ? this->file->symlinkTarget(subfilePath) : QString();
-        default:
-            break;
+        return this->file->type(subfilePath) == DDciFile::Symlink
+                ? this->file->symlinkTarget(subfilePath)
+                : QString();
+    default:
+        break;
     }
 
     return QString();
@@ -539,7 +552,8 @@ void DDciFileEngine::setFileName(const QString &fullPath)
     subfilePath.clear();
 
     const auto paths = resolvePath(fullPath, QString(), false);
-    if (paths.first.isEmpty() || paths.second.isEmpty())
+    if (paths.first.isEmpty()
+            || paths.second.isEmpty())
         return;
 
     dciFilePath = paths.first;
@@ -558,19 +572,21 @@ QDateTime DDciFileEngine::fileTime(QAbstractFileEngine::FileTime time) const
     return QFileInfo(dciFilePath).fileTime(static_cast<QFile::FileTime>(time));
 }
 #endif
-
-#if QT_VERSION >= QT_VERSION_CHECK(6, 8, 0)
-QAbstractFileEngine::IteratorUniquePtr
-DDciFileEngine::beginEntryList(const QString &path, QDir::Filters filters, const QStringList &filterNames)
-{
-    return QAbstractFileEngine::IteratorUniquePtr(new DDciFileEngineIterator(filters, filterNames));
-}
+#if QT_VERSION >= QT_VERSION_CHECK(6, 8, 1)
+QAbstractFileEngine::IteratorUniquePtr DDciFileEngine::beginEntryList(const QString &path, QDirListing::IteratorFlags filters, const QStringList &filterNames)
+#elif QT_VERSION >= QT_VERSION_CHECK(6, 8, 0)
+QAbstractFileEngine::IteratorUniquePtr DDciFileEngine::beginEntryList(const QString &path, QDir::Filters filters, const QStringList &filterNames)
 #else
 DDciFileEngine::Iterator *DDciFileEngine::beginEntryList(QDir::Filters filters, const QStringList &filterNames)
-{
-    return new DDciFileEngineIterator(filters, filterNames);
-}
 #endif
+{
+#if QT_VERSION >= QT_VERSION_CHECK(6, 8, 0)
+    Q_UNUSED(path);
+    return QAbstractFileEngine::IteratorUniquePtr(new DDciFileEngineIterator(filters, filterNames));
+#else
+    return new DDciFileEngineIterator(filters, filterNames);
+#endif
+}
 
 #if QT_VERSION >= QT_VERSION_CHECK(6, 8, 0)
 QAbstractFileEngine::IteratorUniquePtr DDciFileEngine::endEntryList()
@@ -605,10 +621,20 @@ bool DDciFileEngine::supportsExtension(QAbstractFileEngine::Extension extension)
     return extension == AtEndExtension;
 }
 
+#if QT_VERSION >= QT_VERSION_CHECK(6, 10, 0)
+DDciFileEngine::TriStateResult DDciFileEngine::cloneTo(QAbstractFileEngine *target)
+#else
 bool DDciFileEngine::cloneTo(QAbstractFileEngine *target)
+#endif
 {
     const QByteArray &data = file->dataRef(subfilePath);
-    return target->write(data.constData(), data.size()) == data.size();
+    auto ret = target->write(data.constData(), data.size()) == data.size();
+
+#if QT_VERSION >= QT_VERSION_CHECK(6, 10, 0)
+    return ret ? DDciFileEngine::TriStateResult::Success : DDciFileEngine::TriStateResult::Failed;
+#else
+    return ret;
+#endif
 }
 
 bool DDciFileEngine::forceSave(bool writeFile) const
@@ -621,7 +647,9 @@ bool DDciFileEngine::forceSave(bool writeFile) const
     return flushToFile(&file, writeFile);
 }
 
-QPair<QString, QString> DDciFileEngine::resolvePath(const QString &fullPath, const QString &realFilePath, bool needRealFileExists)
+QPair<QString, QString> DDciFileEngine::resolvePath(const QString &fullPath,
+                                                    const QString &realFilePath,
+                                                    bool needRealFileExists)
 {
     if (!fullPath.startsWith(QStringLiteral(DCI_FILE_SCHEME) + realFilePath))
         return {};
@@ -663,8 +691,8 @@ QPair<QString, QString> DDciFileEngine::resolvePath(const QString &fullPath, con
         return {};
 
     subfilePath = QDir::cleanPath(formatFullPath.mid(schemeLength + dciFilePath.length()));
-    qCDebug(
-        logFE(), "The DCI file path is: \"%s\", the subfile path is: \"%s\"", qPrintable(dciFilePath), qPrintable(subfilePath));
+    qCDebug(logFE(), "The DCI file path is: \"%s\", the subfile path is: \"%s\"",
+            qPrintable(dciFilePath), qPrintable(subfilePath));
     Q_ASSERT(!subfilePath.isEmpty());
 
     return qMakePair(dciFilePath, subfilePath);
